@@ -9,12 +9,19 @@ from typing import Union, List
 from bitarray import bitarray
 from bitarray.util import pprint, ba2int, ba2hex, int2ba
 
+
+try:
+    # This import is for unit testing
+    from xtce_generator.src.xtce.msg_post_processor import MsgPostProcessor
+except ModuleNotFoundError:
+    from xtce.msg_post_processor import MsgPostProcessor
+
 try:
     from xtce import xtce, xtce_generator
     from xtce.xtce_generator import XTCEManager
 except ModuleNotFoundError:
-    import xtce.xtce as xtce
-    import xtce.xtce_generator as xtce_generator
+    from  xtce import xtce
+    from  xtce import xtce_generator
     import xtce.xtce_generator.XTCEManager as XTCEManager
 
 from enum import Enum
@@ -23,12 +30,6 @@ import logging
 import yaml
 
 
-END = 0xc0
-ESC = 0xdb
-ESC_END = 0xdc
-ESC_ESC = 0xdd
-
-
 # FIXME:This function should be moved to a pre-processor.
 def extract_bits_from_base_tlm_container(container: dict, comparison: xtce.ComparisonType, container_size: int,
                                          msg_id) -> bitarray:
@@ -494,7 +495,6 @@ class XTCEParser:
         return out_array
 
 
-
     def __get_array_type_arg(self, cmd: xtce.CommandMetaDataType,
                              arg_type_ref: str,
                              spacesystem: xtce.SpaceSystemType) -> list:
@@ -930,7 +930,7 @@ class XTCEParser:
         #         value.append(item)
         return value
 
-    def validate_packet(self, packet: bytes, path: str):
+    def validate_packet(self, packet: bytes, path: str, ):
         """
         Returns the value inside of the packet that path points to, but only if packet is valid.
         The packet is validated based on XTCE rules such as criteria for containers.
@@ -975,7 +975,7 @@ class XTCEParser:
 
         return value
 
-    def craft_tlm_command(self, path: str, args: dict) -> bytes:
+    def craft_tlm_command(self, path: str, args: dict, post_processor: MsgPostProcessor = None) -> bytes:
         """
         Returns a new packet based on path and args. This packet(though queried from XTCE telemetry),
         may be used as a command that can be sent to the vehicle.
@@ -1074,7 +1074,11 @@ class XTCEParser:
                 self.logger.warning(f"No type was found for {param_name + '.' + arg['name']}")
         #         FIXME:Raise exception since we could not find a type and could not craft the message
 
-        return self.slip_encode(bytes(payload_bytes), 12)
+        msg_packet = bytes(payload_bytes)
+        if post_processor is not None:
+            msg_packet = post_processor.process(bytes(payload_bytes))
+
+        return msg_packet
 
     def __set_arg_assignment(self, argument_assignment_list: xtce.ArgumentAssignmentListType,
                              arg_obj: xtce.NameDescriptionType,
@@ -1107,7 +1111,7 @@ class XTCEParser:
                                       length=int(arg_obj.get_IntegerDataEncoding().get_sizeInBits()), endian=in_endian)
         return arg_bits_out
 
-    def craft_command(self, path: str, args: dict) -> bytes:
+    def craft_command(self, path: str, args: dict, post_processor: MsgPostProcessor = None) -> bytes:
         """
         Returns a new packet based on path and args.
         """
@@ -1228,38 +1232,13 @@ class XTCEParser:
         #     else:
         #         logging.warning(f"The packet for {path} is valid, but no type for it was found.")
 
-        # FIXME:This SLIP code should be moved to post/pre-processor
         cmd_bytes = bytearray(payload_bits.tobytes())
-        tmp = cmd_bytes[6]
-        cmd_bytes[7] = tmp
-        cmd_bytes[6] = 0
-        output_bytes = self.slip_encode(bytes(cmd_bytes), 8)
 
-        return output_bytes
+        msg_packet = bytes(cmd_bytes)
+        if post_processor is not None:
+            msg_packet = post_processor.process(bytes(cmd_bytes))
 
-    def slip_encode(self, packet: bytes, header_size: int):
-        payload = bytearray()
-        for character in packet:
-            if len(payload) < header_size:
-                value = struct.unpack('>B', character.to_bytes(1, "big"))[0]  # big-endian
-            else:
-                value = struct.unpack('B', character.to_bytes(1, "little"))[0]  # little-endian
-            if value == END:
-                value = ESC
-                payload.append(value)
-                value = ESC_END
-                payload.append(value)
-            elif value == ESC:
-                value = ESC
-                payload.append(value)
-                value = ESC_ESC
-                payload.append(value)
-                payload.append(character)
-            else:
-                payload.append(character)
-
-        payload.append(END)
-        return bytes(payload)
+        return msg_packet
 
     def get_offset_aggregate(self, params, param_name) -> int:
         """"
